#[repr(C)]pub struct ExecBuffer {
pub gas_left: i64,
pub syscall_symbol: SyscallSymbol,
pub a0: u64,
pub a1: u64,
pub a2: u64,
pub a3: u64,
pub a4: u64,
pub a5: u64,
}Expand description
Buffer shared between runtime and executor for passing syscall data across the host function boundary.
The runtime allocates this on its stack and passes it via pointer.
The host fills it in when returning from crate::Execution::run.
Fields
gas_left: i64Gas remaining after the execution step.
syscall_symbol: SyscallSymbolThe syscall symbol (only meaningful when the status is ExecStatus::Syscall).
a0: u64Syscall register arguments a0-a5 (only meaningful for ExecStatus::Syscall).
a1: u64a2: u64a3: u64a4: u64a5: u64Trait Implementations
Sourceimpl AsMut<[u8]> for ExecBuffer
impl AsMut<[u8]> for ExecBuffer
Sourceimpl AsRef<[u8]> for ExecBuffer
impl AsRef<[u8]> for ExecBuffer
Sourceimpl Debug for ExecBuffer
impl Debug for ExecBuffer
Sourceimpl Default for ExecBuffer
impl Default for ExecBuffer
Sourcefn default() -> ExecBuffer
fn default() -> ExecBuffer
Returns the “default value” for a type. Read more